@@ -34,9 +34,9 @@ fn main() -> Result<(), ParseError> {
     let duration = end_time - start_time;
 
     if no_unit {
-        println!("{}", duration.num_days());
+        println!("{}", duration.num_seconds());
     } else {
-        println!("{} d", duration.num_days());
+        println!("{} s", duration.num_seconds());
     };
 
     Ok(())
